==> v8.3.zip: ru_twords_ru_tw/bible/other/goat.md <==
# козёл, коза, козлёнок

## Определение:

Козёл — четвероногое парнокопытное животное семейства полорогих с длинной шерстью, выращиваемое в основном для получения молока и мяса. Коза — это самка козла, козлёнок — детёныш козла.

* Козлы, как и овцы, считались “чистыми” животными, то есть годными для жертвоприношений, в том числе для тех, что совершались во время праздника Пасхи.

* Несмотря на то, что козлы, как и овцы, являются домашними животными, они отличаются друг от друга:

  * У козлов шерсть тёмная и грубая, а у овец — мягкая.
  * Козлы любопытны, они никогда не пасутся группами и не идут за пастухом. Овцы же всегда держатся стадом и следуют за пастухом.

* В древние времена козы являлись главным источником молока в Израиле.
* Их шкуры использовались для изготовления шатров и бурдюков.
* Ветхом и в Новом Заветах козлы символизируют грешных людей — возможно потому, что они убегают от пастуха, который о них заботится.
* Израильтяне приносили козлов в жертву за грех. В ходе жертвоприношения одного козла убивали, а на другого священник возлагал руки и отпускал его в пустыню. Это действие символизировало отпущение грехов.

(См. также: [стадо](../other/flock.md), [жертва](../other/sacrifice.md), [овца](../other/sheep.md), [праведный](../kt/righteous.md), [вино](../other/wine.md))

## Ссылки на библейский текст:

* [Исх. 12:3-4](rc://*/tn/help/exo/12/03)
* [Быт. 30:31-32](rc://*/tn/help/gen/30/31)
* [Быт. 31:10-11](rc://*/tn/help/gen/31/10)
* [Быт. 37:31-33](rc://*/tn/help/gen/37/31)
* [Лев. 3:12-14](rc://*/tn/help/lev/03/12)
* [Мф. 25:31-33](rc://*/tn/help/mat/25/31)

## Данные о слове:

* Номера Стронга: H689, H1423, H1429, H1601, H3277, H3629, H5795, H5796, H6260, H6629, H6842, H6939, H7716, H8163, H8166, H8495, G122, G2055, G2056, G5131

==> v9.2.zip: ru_twords_ru_tw/bible/other/goat.md <==
# козёл, коза, козлёнок
## Определение:

Козёл — четвероногое парнокопытное животное семейства полорогих с длинной шерстью, выращиваемое в основном для получения молока и мяса. Коза — это самка козла, козлёнок — детёныш козла.

* Козлы, как и овцы, считались “чистыми” животными, то есть годными для жертвоприношений, в том числе для тех, что совершались во время праздника Пасхи.  

* Несмотря на то, что козлы, как и овцы, являются домашними животными, они отличаются друг от друга:
         
      * У козлов шерсть тёмная и грубая, а у овец — мягкая.
      * Козлы любопытны, они никогда не пасутся группами и не идут за пастухом. Овцы же всегда держатся стадом и следуют за пастухом.      
         
* В древние времена козы являлись главным источником молока в Израиле.
* Их шкуры использовались для изготовления шатров и бурдюков.
* Ветхом и в Новом Заветах козлы символизируют грешных людей — возможно потому, что они убегают от пастуха, который о них заботится.
* Израильтяне приносили козлов в жертву за грех. В ходе жертвоприношения одного козла убивали, а на другого священник возлагал руки и отпускал его в пустыню. Это действие символизировало отпущение грехов. 

(См. также: [стадо](../other/flock.md), [жертва](../other/sacrifice.md), [овца](../other/sheep.md), [праведный](../kt/righteous.md), [вино](../other/wine.md))

## Ссылки на библейский текст:

* [Исх. 12:3-4](rc://ru/tn/help/exo/12/03)
* [Быт. 30:31-32](rc://ru/tn/help/gen/30/31)
* [Быт. 31:10-11](rc://ru/tn/help/gen/31/10)
* [Быт. 37:31-33](rc://ru/tn/help/gen/37/31)
* [Лев. 3:12-14](rc://ru/tn/help/lev/03/12)
* [Мф. 25:31-33](rc://ru/tn/help/mat/25/31)

## Данные о слове:

* Номера Стронга: H689, H1423, H1429, H1601, H3277, H3629, H5795, H5796, H6260, H6629, H6842, H6939, H7716, H8163, H8166, H8495, G122, G2055, G2056, G5131
